# Generated by Django 3.1.6 on 2021-06-09 18:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='page',
            options={'ordering': ['category', '-priority'], 'verbose_name': 'Categorized page', 'verbose_name_plural': 'Categorized pages'},
        ),
    ]
