# Generated by Django 3.1.6 on 2021-06-21 06:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0002_auto_20210609_2039'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='page',
            options={'ordering': ['category', 'priority'], 'verbose_name': 'Categorized page', 'verbose_name_plural': 'Categorized pages'},
        ),
        migrations.AddField(
            model_name='attachment',
            name='title',
            field=models.CharField(default='', max_length=250),
            preserve_default=False,
        ),
    ]
